==> java-sdk-1.0.0-20200603.110828-24-sources.jar: com/phonepe/sdk/javasdk/transaction/init/AccountConstraintsTransactionComponent.java <==
package com.phonepe.sdk.javasdk.transaction.init;

import com.phonepe.sdk.javasdk.transaction.init.models.AllowedAccountConstraint;
import com.phonepe.sdk.javasdk.transaction.init.models.InitRequest;
import com.phonepe.sdk.javasdk.transaction.init.models.MerchantConstraints;
import com.phonepe.sdk.javasdk.transaction.init.models.MerchantContext;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

@Slf4j
public class AccountConstraintsTransactionComponent extends TransactionInitDecorator{

    private TransactionInitComponent transactionInitComponent;
    private List<AllowedAccountConstraint> allowedAccountConstraints;

    public AccountConstraintsTransactionComponent(final TransactionInitComponent transactionInitComponent,
                                                  final List<AllowedAccountConstraint> allowedAccountConstraints) {
        super(transactionInitComponent);
        this.allowedAccountConstraints = allowedAccountConstraints;
    }

    @Override
    public InitRequest getInitRequest(String merchantId,
                                      String transactionId,
                                      Long amount) {
        InitRequest initRequest = this.transactionInitComponent.getInitRequest(merchantId, transactionId, amount);
        MerchantContext merchantContext = initRequest.getMerchantContext();
        MerchantConstraints merchantConstraints = MerchantConstraints.builder()
                                                                     .account(this.allowedAccountConstraints)
                                                                     .build();
        merchantContext.setConstraints(merchantConstraints);
        initRequest.setMerchantContext(merchantContext);
        return initRequest;
    }
}

==> java-sdk-1.0.0-20200603.115353-29-sources.jar: com/phonepe/sdk/javasdk/transaction/init/AccountConstraintsTransactionComponent.java <==
package com.phonepe.sdk.javasdk.transaction.init;

import com.phonepe.sdk.javasdk.transaction.init.models.AllowedAccountConstraint;
import com.phonepe.sdk.javasdk.transaction.init.models.InitRequest;
import com.phonepe.sdk.javasdk.transaction.init.models.MerchantConstraints;
import com.phonepe.sdk.javasdk.transaction.init.models.MerchantContext;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

@Slf4j
public class AccountConstraintsTransactionComponent extends TransactionInitDecorator{

    private TransactionInitComponent transactionInitComponent;
    private List<AllowedAccountConstraint> allowedAccountConstraints;

    public AccountConstraintsTransactionComponent(final TransactionInitComponent transactionInitComponent,
                                                  final List<AllowedAccountConstraint> allowedAccountConstraints) {
        super(transactionInitComponent);
        this.allowedAccountConstraints = allowedAccountConstraints;
    }

    @Override
    public InitRequest getInitRequest(String merchantId,
                                      String userId,
                                      String transactionId,
                                      Long amount) {
        InitRequest initRequest = this.transactionInitComponent.getInitRequest(merchantId, userId, transactionId, amount);
        MerchantContext merchantContext = initRequest.getMerchantContext();
        MerchantConstraints merchantConstraints = MerchantConstraints.builder()
                                                                     .account(this.allowedAccountConstraints)
                                                                     .build();
        merchantContext.setConstraints(merchantConstraints);
        initRequest.setMerchantContext(merchantContext);
        return initRequest;
    }
}
